API Reference
=============

.. toctree::
   :maxdepth: 3

   kernel_compile_and_call.rst
   enums.rst
   simplifications.rst
   datahandling.rst
   configuration.rst
   field.rst
   stencil.rst
   finite_differences.rst
   plot.rst
   ast.rst
